<div align="center">

# pyfuelprices

A generic python module to retrieve fuel prices for different fuel suppliers.

[![Build Status](https://github.com/pantherale0/pyfuelprices/workflows/build/badge.svg)](https://github.com/pantherale0/pyfuelprices/actions)
[![Coverage Status](https://coveralls.io/repos/github/pantherale0/pyfuelprices/badge.svg?branch=main)](https://coveralls.io/github/pantherale0/pyfuelprices?branch=main)
[![PyPi](https://img.shields.io/pypi/v/pyfuelprices)](https://pypi.org/project/pyfuelprices)
[![Licence](https://img.shields.io/github/license/pantherale0/pyfuelprices)](LICENSE)

</div>

## Install

```bash
# Install tool
pip3 install pyfuelprices

# Install locally
just install
```

## Usage

TODO

## Development

```bash
# Get a comprehensive list of development tools
just --list
```
